==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/lists/list-3.php <==
<?php
return array (
  123 => true,
  'sex' => true,
  'mad' => true,
  'ass' => true,
  198 => true,
  'xxx' => true,
  'man' => true,
  'amo' => true,
  'dog' => true,
  197 => true,
  '000' => true,
  'eek' => true,
  'one' => true,
  'bob' => true,
  666 => true,
  199 => true,
  111 => true,
  'hot' => true,
  'kin' => true,
  'red' => true,
  'cat' => true,
  'boy' => true,
  '007' => true,
  'you' => true,
  'hol' => true,
  'aaa' => true,
  200 => true,
  'abc' => true,
  'now' => true,
  'big' => true,
  'asd' => true,
  196 => true,
  'sam' => true,
  'cum' => true,
  'ale' => true,
  201 => true,
  'lui' => true,
  'joe' => true,
  777 => true,
  'tom' => true,
  'loc' => true,
  'beb' => true,
  101 => true,
  'max' => true,
  'lee' => true,
  'com' => true,
  'y2k' => true,
  'net' => true,
  'gay' => true,
  'fun' => true,
  195 => true,
  'off' => true,
  'lol' => true,
  'jos' => true,
  'dan' => true,
  420 => true,
  333 => true,
  '0px' => true,
  'rob' => true,
  'fox' => true,
  'end' => true,
  555 => true,
  252 => true,
  232 => true,
  210 => true,
  'tai' => true,
  'put' => true,
  'pie' => true,
  'mar' => true,
  'ice' => true,
  'cha' => true,
  'ben' => true,
  969 => true,
  202 => true,
  '1px' => true,
  'rat' => true,
  'ppp' => true,
  'pat' => true,
  'lul' => true,
  'gat' => true,
  'bat' => true,
  '5px' => true,
  '3px' => true,
  321 => true,
  258 => true,
  242 => true,
  112 => true,
  'yes' => true,
  'wet' => true,
  'tit' => true,
  'out' => true,
  'nen' => true,
  'mam' => true,
  'lov' => true,
  'leo' => true,
  'god' => true,
  'gab' => true,
  'eat' => true,
  'car' => true,
  'bet' => true,
  'all' => true,
  999 => true,
  888 => true,
  456 => true,
  '2px' => true,
  222 => true,
  211 => true,
  180 => true,
  140 => true,
  121 => true,
  120 => true,
  '051' => true,
  '001' => true,
  'tim' => true,
  'the' => true,
  'sol' => true,
  'qwe' => true,
  'qqq' => true,
  'pen' => true,
  'pap' => true,
  'mik' => true,
  'mac' => true,
  'jua' => true,
  'jim' => true,
  'jho' => true,
  'jay' => true,
  'eve' => true,
  'die' => true,
  'day' => true,
  'dad' => true,
  'cas' => true,
  'box' => true,
  'bar' => true,
  'ace' => true,
  900 => true,
  '4px' => true,
  316 => true,
  230 => true,
  151 => true,
  131 => true,
  110 => true,
  102 => true,
  100 => true,
  '???' => true,
  'zxc' => true,
  'www' => true,
  'wow' => true,
  'two' => true,
  'sss' => true,
  'son' => true,
  'sin' => true,
  'oma' => true,
  'not' => true,
  'mom' => true,
  'mdj' => true,
  'lun' => true,
  'lal' => true,
  'kat' => true,
  'joy' => true,
  'jon' => true,
  'job' => true,
  'jam' => true,
  'her' => true,
  'fly' => true,
  'fan' => true,
  'doo' => true,
  'chi' => true,
  'bbb' => true,
  'bad' => true,
  'ana' => true,
  'abe' => true,
  911 => true,
  444 => true,
  292 => true,
  291 => true,
  213 => true,
  212 => true,
  190 => true,
  162 => true,
  160 => true,
  159 => true,
  135 => true,
  '082' => true,
  'yui' => true,
  'vip' => true,
  'too' => true,
  'tat' => true,
  'sux' => true,
  'sus' => true,
  'sau' => true,
  'rsu' => true,
  'rom' => true,
  'rol' => true,
  'ray' => true,
  'pop' => true,
  'pit' => true,
  'pip' => true,
  'pia' => true,
  'new' => true,
  'nel' => true,
  'mmm' => true,
  'mia' => true,
  'mel' => true,
  'lob' => true,
  'kkk' => true,
  'kid' => true,
  'hhh' => true,
  'fob' => true,
  'flo' => true,
  'ert' => true,
  'dot' => true,
  'dio' => true,
  'ded' => true,
  'ddd' => true,
  'cul' => true,
  'can' => true,
  'boo' => true,
  'aol' => true,
  'ant' => true,
  789 => true,
  741 => true,
  505 => true,
  313 => true,
  290 => true,
  257 => true,
  246 => true,
  234 => true,
  170 => true,
  161 => true,
  152 => true,
  147 => true,
  145 => true,
  132 => true,
  127 => true,
  125 => true,
  124 => true,
  '050' => true,
  '020' => true,
  'zzz' => true,
  'wes' => true,
  'web' => true,
  'von' => true,
  'viv' => true,
  'val' => true,
  'usa' => true,
  'tre' => true,
  'top' => true,
  'tet' => true,
  'ter' => true,
  'tar' => true,
  'sys' => true,
  'sof' => true,
  'sis' => true,
  'set' => true,
  'sec' => true,
  'pol' => true,
  'pin' => true,
  'pig' => true,
  'pet' => true,
  'par' => true,
  'old' => true,
  'nul' => true,
  'nan' => true,
  'nad' => true,
  'mum' => true,
  'moe' => true,
  'mil' => true,
  'me2' => true,
  'mdf' => true,
  'mda' => true,
  'md5' => true,
  'mas' => true,
  'lok' => true,
  'kay' => true,
  'joh' => true,
  'jes' => true,
  'jai' => true,
  'iva' => true,
  'hax' => true,
  'gwn' => true,
  'gun' => true,
  'for' => true,
  'foo' => true,
  'fla' => true,
  'eva' => true,
  'est' => true,
  'dvd' => true,
  'due' => true,
  'don' => true,
  'doe' => true,
  'des' => true,
  'def' => true,
  'dee' => true,
  'cru' => true,
  'cri' => true,
  'cel' => true,
  'cec' => true,
  'ccc' => true,
  'cam' => true,
  'cal' => true,
  'bud' => true,
  'btt' => true,
  'bos' => true,
  'bee' => true,
  'asp' => true,
  'ann' => true,
  'amy' => true,
  'ali' => true,
  'alf' => true,
  'ala' => true,
  'air' => true,
  989 => true,
  865 => true,
  770 => true,
  747 => true,
  '6px' => true,
  610 => true,
  455 => true,
  454 => true,
  431 => true,
  369 => true,
  331 => true,
  320 => true,
  303 => true,
  301 => true,
  296 => true,
  269 => true,
  267 => true,
  261 => true,
  241 => true,
  240 => true,
  221 => true,
  218 => true,
  208 => true,
  191 => true,
  188 => true,
  181 => true,
  150 => true,
  141 => true,
  134 => true,
  122 => true,
  113 => true,
  106 => true,
  '080' => true,
  '069' => true,
  '031' => true,
  'zen' => true,
  'zac' => true,
  'z71' => true,
  'yup' => true,
  'yoy' => true,
  'yar' => true,
  'yan' => true,
  'xpw' => true,
  'xec' => true,
  'wtf' => true,
  'wjj' => true,
  'war' => true,
  'vid' => true,
  'van' => true,
  'use' => true,
  'uru' => true,
  'url' => true,
  'uea' => true,
  'tri' => true,
  'toy' => true,
  'tot' => true,
  'tob' => true,
  'tlc' => true,
  'tic' => true,
  'thx' => true,
  'ten' => true,
  'taz' => true,
  'tan' => true,
  'tam' => true,
  'tag' => true,
  'swm' => true,
  'spc' => true,
  'sme' => true,
  'sly' => true,
  'sir' => true,
  'sid' => true,
  'sha' => true,
  'sep' => true,
  'sas' => true,
  'sar' => true,
  'sap' => true,
  'san' => true,
  'sal' => true,
  'rxd' => true,
  'rvd' => true,
  'rus' => true,
  'rui' => true,
  'ros' => true,
  'ror' => true,
  'rod' => true,
  'roc' => true,
  'rey' => true,
  'rew' => true,
  'rev' => true,
  'ren' => true,
  'rcf' => true,
  'rau' => true,
  'rar' => true,
  'raf' => true,
  'r3v' => true,
  'pug' => true,
  'pub' => true,
  'psf' => true,
  'pro' => true,
  'pot' => true,
  'poo' => true,
  'pil' => true,
  'pic' => true,
  'per' => true,
  'pec' => true,
  'pay' => true,
  'pau' => true,
  'pas' => true,
  'pan' => true,
  'pam' => true,
  'pal' => true,
  'paj' => true,
  'pac' => true,
  'owl' => true,
  'oop' => true,
  'nyc' => true,
  'nom' => true,
  'nob' => true,
  'nit' => true,
  'nip' => true,
  'nin' => true,
  'nig' => true,
  'nic' => true,
  'ney' => true,
  'neo' => true,
  'nat' => true,
  'nai' => true,
  'mya' => true,
  'mut' => true,
  'mud' => true,
  'mon' => true,
  'mod' => true,
  'mnm' => true,
  'mis' => true,
  'mim' => true,
  'men' => true,
  'mdz' => true,
  'mdx' => true,
  'mdw' => true,
  'mds' => true,
  'mdn' => true,
  'mdh' => true,
  'mdg' => true,
  'mde' => true,
  'md3' => true,
  'md2' => true,
  'md0' => true,
  'may' => true,
  'low' => true,
  'los' => true,
  'lor' => true,
  'lop' => true,
  'lin' => true,
  'lim' => true,
  'lil' => true,
  'lex' => true,
  'lar' => true,
  'klm' => true,
  'kit' => true,
  'kak' => true,
  'jjj' => true,
  'jen' => true,
  'jds' => true,
  'jan' => true,
  'jak' => true,
  'its' => true,
  'inc' => true,
  'ias' => true,
  'ian' => true,
  'hug' => true,
  'hsf' => true,
  'hit' => true,
  'him' => true,
  'hck' => true,
  'hay' => true,
  'hat' => true,
  'guy' => true,
  'gus' => true,
  'gum' => true,
  'gt+' => true,
  'grg' => true,
  'gra' => true,
  'gnr' => true,
  'giu' => true,
  'gio' => true,
  'ghe' => true,
  'ggo' => true,
  'gas' => true,
  'gap' => true,
  'gal' => true,
  'fur' => true,
  'ful' => true,
  'fuc' => true,
  'fin' => true,
  'fff' => true,
  'eye' => true,
  'err' => true,
  'epw' => true,
  'epc' => true,
  'eno' => true,
  '+en' => true,
  'doc' => true,
  'dlj' => true,
  'der' => true,
  'dep' => true,
  'cup' => true,
  'cuc' => true,
  'cow' => true,
  'coc' => true,
  'cjo' => true,
  'che' => true,
  'ced' => true,
  'cci' => true,
  'c0c' => true,
  'bye' => true,
  'bum' => true,
  'bug' => true,
  'bro' => true,
  'bra' => true,
  'bow' => true,
  'bor' => true,
  'bol' => true,
  'boc' => true,
  'ber' => true,
  'bbc' => true,
  'bay' => true,
  'bag' => true,
  'bab' => true,
  'azu' => true,
  'ase' => true,
  'asa' => true,
  'art' => true,
  'arm' => true,
  'and' => true,
  'ami' => true,
  'age' => true,
  'abb' => true,
  'ab1' => true,
  'aas' => true,
  '9am' => true,
  987 => true,
  972 => true,
  951 => true,
  949 => true,
  947 => true,
  '92p' => true,
  923 => true,
  901 => true,
  '88x' => true,
  863 => true,
  862 => true,
  '85z' => true,
  840 => true,
  831 => true,
  824 => true,
  817 => true,
  802 => true,
  '79y' => true,
  '79e' => true,
  792 => true,
  788 => true,
  753 => true,
  '72f' => true,
  728 => true,
  725 => true,
  720 => true,
  '71q' => true,
  712 => true,
  698 => true,
  696 => true,
  691 => true,
  683 => true,
  654 => true,
  652 => true,
  627 => true,
  617 => true,
  611 => true,
  '59l' => true,
  '59j' => true,
  596 => true,
  592 => true,
  582 => true,
  580 => true,
  570 => true,
  '56n' => true,
  558 => true,
  '53s' => true,
  526 => true,
  512 => true,
  '4me' => true,
  486 => true,
  '46t' => true,
  '45e' => true,
  452 => true,
  450 => true,
  448 => true,
  432 => true,
  430 => true,
  '42w' => true,
  414 => true,
  411 => true,
  '40v' => true,
  '40t' => true,
  406 => true,
  401 => true,
  390 => true,
  389 => true,
  384 => true,
  '37u' => true,
  379 => true,
  378 => true,
  359 => true,
  346 => true,
  '33x' => true,
  335 => true,
  327 => true,
  '31m' => true,
  318 => true,
  310 => true,
  304 => true,
  300 => true,
  299 => true,
  283 => true,
  282 => true,
  280 => true,
  271 => true,
  264 => true,
  263 => true,
  262 => true,
  260 => true,
  259 => true,
  255 => true,
  '24k' => true,
  238 => true,
  237 => true,
  233 => true,
  231 => true,
  223 => true,
  220 => true,
  '21o' => true,
  214 => true,
  '20i' => true,
  205 => true,
  203 => true,
  194 => true,
  192 => true,
  187 => true,
  184 => true,
  179 => true,
  176 => true,
  173 => true,
  171 => true,
  169 => true,
  163 => true,
  '15x' => true,
  156 => true,
  153 => true,
  146 => true,
  144 => true,
  143 => true,
  136 => true,
  128 => true,
  126 => true,
  118 => true,
  116 => true,
  115 => true,
  114 => true,
  '098' => true,
  '094' => true,
  '091' => true,
  '081' => true,
  '052' => true,
  '041' => true,
  '040' => true,
  '035' => true,
  '032' => true,
  '022' => true,
  '021' => true,
  '012' => true,
  '010' => true,
  '***' => true,
  'zyj' => true,
  'zxl' => true,
  'zv2' => true,
  'zub' => true,
  'zsm' => true,
  'zqx' => true,
  'zog' => true,
  'zoe' => true,
  'zn0' => true,
  'zln' => true,
  'zk4' => true,
  'zjp' => true,
  'zip' => true,
  'zia' => true,
  'zha' => true,
  'zgn' => true,
  'zgh' => true,
  'zep' => true,
  'zee' => true,
  'zcf' => true,
  'zaz' => true,
  'zax' => true,
  'zaq' => true,
  'zap' => true,
  'zab' => true,
  'z9q' => true,
  'z86' => true,
  'z61' => true,
  'z0q' => true,
  'yyy' => true,
  'ywy' => true,
  'yuy' => true,
  'yur' => true,
  'yuj' => true,
  'yuc' => true,
  'ysu' => true,
  'ysb' => true,
  'ys3' => true,
  'yrv' => true,
  'yre' => true,
  'yr7' => true,
  'yok' => true,
  'ynl' => true,
  'ymd' => true,
  'ym4' => true,
  'ylo' => true,
  'yl3' => true,
  'yir' => true,
  'yhy' => true,
  'yhu' => true,
  'yey' => true,
  'yen' => true,
  'ydv' => true,
  'yby' => true,
  'ybe' => true,
  'yam' => true,
  'yak' => true,
  'xyk' => true,
  'xxl' => true,
  'xvi' => true,
  'xuy' => true,
  'xux' => true,
  'xuo' => true,
  'xty' => true,
  'xtc' => true,
  'xqt' => true,
  'xpb' => true,
  'xp0' => true,
  'xox' => true,
  'xof' => true,
  'xim' => true,
  'xia' => true,
  'xi9' => true,
  'xhr' => true,
  'xgb' => true,
  'x82' => true,
  'x75' => true,
  'x68' => true,
  'x2y' => true,
  'x27' => true,
  'x0a' => true,
  'wwf' => true,
  'wuo' => true,
  'wty' => true,
  'wtp' => true,
  'wsb' => true,
  'wrd' => true,
  'wr3' => true,
  'wp9' => true,
  'woo' => true,
  'wol' => true,
  'wo2' => true,
  'wns' => true,
  'wku' => true,
  'wkk' => true,
  'wjr' => true,
  'wjo' => true,
  'wjg' => true,
  'wip' => true,
  'win' => true,
  'wil' => true,
  'wic' => true,
  'wi1' => true,
  'who' => true,
  'wg0' => true,
  'wen' => true,
  'wel' => true,
  'wef' => true,
  'wee' => true,
  'wbb' => true,
  'way' => true,
  'wax' => true,
  'waw' => true,
  'was' => true,
  'wal' => true,
  'w82' => true,
  'vyn' => true,
  'vxf' => true,
  'vvv' => true,
  'vuk' => true,
  'vuj' => true,
  'vtt' => true,
  'vny' => true,
  'vlp' => true,
  'vl9' => true,
  'vkq' => true,
  'vjq' => true,
);

==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/lists/list-3.php <==
<?php
return array (
  123 => true,
  'sex' => true,
  'mad' => true,
  'ass' => true,
  198 => true,
  'xxx' => true,
  'man' => true,
  'amo' => true,
  'dog' => true,
  197 => true,
  '000' => true,
  'eek' => true,
  'one' => true,
  'bob' => true,
  666 => true,
  199 => true,
  111 => true,
  'hot' => true,
  'kin' => true,
  'red' => true,
  'cat' => true,
  'boy' => true,
  '007' => true,
  'you' => true,
  'hol' => true,
  'aaa' => true,
  200 => true,
  'abc' => true,
  'now' => true,
  'big' => true,
  'asd' => true,
  196 => true,
  'sam' => true,
  'cum' => true,
  'ale' => true,
  201 => true,
  'lui' => true,
  'joe' => true,
  777 => true,
  'tom' => true,
  'loc' => true,
  'beb' => true,
  101 => true,
  'max' => true,
  'lee' => true,
  'com' => true,
  'y2k' => true,
  'net' => true,
  'gay' => true,
  'fun' => true,
  195 => true,
  'off' => true,
  'lol' => true,
  'jos' => true,
  'dan' => true,
  420 => true,
  333 => true,
  '0px' => true,
  'rob' => true,
  'fox' => true,
  'end' => true,
  555 => true,
  252 => true,
  232 => true,
  210 => true,
  'tai' => true,
  'put' => true,
  'pie' => true,
  'mar' => true,
  'ice' => true,
  'cha' => true,
  'ben' => true,
  969 => true,
  202 => true,
  '1px' => true,
  'rat' => true,
  'ppp' => true,
  'pat' => true,
  'lul' => true,
  'gat' => true,
  'bat' => true,
  '5px' => true,
  '3px' => true,
  321 => true,
  258 => true,
  242 => true,
  112 => true,
  'yes' => true,
  'wet' => true,
  'tit' => true,
  'out' => true,
  'nen' => true,
  'mam' => true,
  'lov' => true,
  'leo' => true,
  'god' => true,
  'gab' => true,
  'eat' => true,
  'car' => true,
  'bet' => true,
  'all' => true,
  999 => true,
  888 => true,
  456 => true,
  '2px' => true,
  222 => true,
  211 => true,
  180 => true,
  140 => true,
  121 => true,
  120 => true,
  '051' => true,
  '001' => true,
  'tim' => true,
  'the' => true,
  'sol' => true,
  'qwe' => true,
  'qqq' => true,
  'pen' => true,
  'pap' => true,
  'mik' => true,
  'mac' => true,
  'jua' => true,
  'jim' => true,
  'jho' => true,
  'jay' => true,
  'eve' => true,
  'die' => true,
  'day' => true,
  'dad' => true,
  'cas' => true,
  'box' => true,
  'bar' => true,
  'ace' => true,
  '???' => true,
  900 => true,
  '4px' => true,
  316 => true,
  230 => true,
  151 => true,
  131 => true,
  110 => true,
  102 => true,
  100 => true,
  'zxc' => true,
  'www' => true,
  'wow' => true,
  'two' => true,
  'sss' => true,
  'son' => true,
  'sin' => true,
  'oma' => true,
  'not' => true,
  'mom' => true,
  'lun' => true,
  'lal' => true,
  'kat' => true,
  'joy' => true,
  'jon' => true,
  'job' => true,
  'jam' => true,
  'her' => true,
  'fly' => true,
  'fan' => true,
  'doo' => true,
  'bbb' => true,
  'bad' => true,
  'ana' => true,
  'abe' => true,
  'mdj' => true,
  'chi' => true,
  911 => true,
  444 => true,
  292 => true,
  291 => true,
  213 => true,
  212 => true,
  190 => true,
  162 => true,
  160 => true,
  159 => true,
  135 => true,
  '082' => true,
  'yui' => true,
  'vip' => true,
  'too' => true,
  'tat' => true,
  'sux' => true,
  'sus' => true,
  'sau' => true,
  'rom' => true,
  'rol' => true,
  'ray' => true,
  'pop' => true,
  'pit' => true,
  'pip' => true,
  'pia' => true,
  'new' => true,
  'nel' => true,
  'mmm' => true,
  'mia' => true,
  'mel' => true,
  'lob' => true,
  'kkk' => true,
  'kid' => true,
  'hhh' => true,
  'fob' => true,
  'flo' => true,
  'ert' => true,
  'dot' => true,
  'dio' => true,
  'ded' => true,
  'ddd' => true,
  'cul' => true,
  'can' => true,
  'boo' => true,
  'aol' => true,
  'ant' => true,
  'rsu' => true,
  789 => true,
  741 => true,
  505 => true,
  313 => true,
  290 => true,
  257 => true,
  246 => true,
  234 => true,
  170 => true,
  161 => true,
  152 => true,
  147 => true,
  145 => true,
  132 => true,
  127 => true,
  125 => true,
  124 => true,
  '050' => true,
  '020' => true,
  'zzz' => true,
  'wes' => true,
  'web' => true,
  'von' => true,
  'viv' => true,
  'val' => true,
  'usa' => true,
  'tre' => true,
  'top' => true,
  'tet' => true,
  'ter' => true,
  'tar' => true,
  'sof' => true,
  'sis' => true,
  'set' => true,
  'sec' => true,
  'pol' => true,
  'pin' => true,
  'pig' => true,
  'pet' => true,
  'par' => true,
  'old' => true,
  'nul' => true,
  'nan' => true,
  'nad' => true,
  'mum' => true,
  'moe' => true,
  'mil' => true,
  'me2' => true,
  'mas' => true,
  'lok' => true,
  'kay' => true,
  'joh' => true,
  'jes' => true,
  'jai' => true,
  'iva' => true,
  'hax' => true,
  'gwn' => true,
  'gun' => true,
  'for' => true,
  'foo' => true,
  'fla' => true,
  'eva' => true,
  'est' => true,
  'dvd' => true,
  'due' => true,
  'don' => true,
  'doe' => true,
  'des' => true,
  'def' => true,
  'dee' => true,
  'cru' => true,
  'cri' => true,
  'cel' => true,
  'cec' => true,
  'ccc' => true,
  'cam' => true,
  'cal' => true,
  'bud' => true,
  'btt' => true,
  'bos' => true,
  'bee' => true,
  'asp' => true,
  'ann' => true,
  'amy' => true,
  'ali' => true,
  'alf' => true,
  'ala' => true,
  'air' => true,
  'sys' => true,
  'mdf' => true,
  'mda' => true,
  'md5' => true,
  989 => true,
  865 => true,
  770 => true,
  747 => true,
  '6px' => true,
  610 => true,
  455 => true,
  454 => true,
  431 => true,
  369 => true,
  331 => true,
  320 => true,
  303 => true,
  301 => true,
  296 => true,
  269 => true,
  267 => true,
  261 => true,
  241 => true,
  240 => true,
  221 => true,
  218 => true,
  208 => true,
  191 => true,
  188 => true,
  181 => true,
  150 => true,
  141 => true,
  134 => true,
  122 => true,
  113 => true,
  106 => true,
  '080' => true,
  '069' => true,
  '031' => true,
  'zen' => true,
  'zac' => true,
  'z71' => true,
  'yup' => true,
  'yar' => true,
  'yan' => true,
  'xpw' => true,
  'xec' => true,
  'wtf' => true,
  'war' => true,
  'wjj' => true,
  'vid' => true,
  'van' => true,
  'use' => true,
  'uru' => true,
  'url' => true,
  'uea' => true,
  'tot' => true,
  'tob' => true,
  'tlc' => true,
  'tic' => true,
  'ten' => true,
  'taz' => true,
  'tan' => true,
  'tam' => true,
  'tag' => true,
  'swm' => true,
  'spc' => true,
  'sou' => true,
  'sme' => true,
  'sly' => true,
  'sir' => true,
  'sid' => true,
  'sha' => true,
  'sep' => true,
  'sas' => true,
  'sar' => true,
  'sap' => true,
  'san' => true,
  'sal' => true,
  'rvd' => true,
  'rus' => true,
  'rui' => true,
  'ros' => true,
  'ror' => true,
  'rod' => true,
  'roc' => true,
  'rey' => true,
  'rew' => true,
  'rev' => true,
  'ren' => true,
  'rcf' => true,
  'rau' => true,
  'rar' => true,
  'raf' => true,
  'r3v' => true,
  'pug' => true,
  'pub' => true,
  'psf' => true,
  'pot' => true,
  'poo' => true,
  'pil' => true,
  'pic' => true,
  'per' => true,
  'pec' => true,
  'pay' => true,
  'pau' => true,
  'pas' => true,
  'pan' => true,
  'pam' => true,
  'pal' => true,
  'paj' => true,
  'pac' => true,
  'owl' => true,
  'oop' => true,
  'nyc' => true,
  'nom' => true,
  'nob' => true,
  'nit' => true,
  'nip' => true,
  'nin' => true,
  'nig' => true,
  'nic' => true,
  'ney' => true,
  'neo' => true,
  'nat' => true,
  'nai' => true,
  'mya' => true,
  'mut' => true,
  'mud' => true,
  'mon' => true,
  'mod' => true,
  'mnm' => true,
  'mis' => true,
  'mim' => true,
  'men' => true,
  'may' => true,
  'low' => true,
  'los' => true,
  'lor' => true,
  'lop' => true,
  'lin' => true,
  'lim' => true,
  'lil' => true,
  'lex' => true,
  'lar' => true,
  'klm' => true,
  'kit' => true,
  'kak' => true,
  'jjj' => true,
  'jen' => true,
  'jds' => true,
  'jan' => true,
  'jak' => true,
  'its' => true,
  'inc' => true,
  'ias' => true,
  'ian' => true,
  'hug' => true,
  'hsf' => true,
  'hit' => true,
  'him' => true,
  'hck' => true,
  'hay' => true,
  'hat' => true,
  'guy' => true,
  'gus' => true,
  'gum' => true,
  'grg' => true,
  'gra' => true,
  'gnr' => true,
  'gio' => true,
  'ghe' => true,
  'ggo' => true,
  'gas' => true,
  'gap' => true,
  'gal' => true,
  'fur' => true,
  'ful' => true,
  'fuc' => true,
  'fin' => true,
  'fff' => true,
  'eye' => true,
  'err' => true,
  'epc' => true,
  'eno' => true,
  'doc' => true,
  'dlj' => true,
  'der' => true,
  'dep' => true,
  'cup' => true,
  'cuc' => true,
  'cow' => true,
  'coc' => true,
  'cjo' => true,
  'che' => true,
  'ced' => true,
  'cci' => true,
  'c0c' => true,
  'bye' => true,
  'bum' => true,
  'bug' => true,
  'bro' => true,
  'bra' => true,
  'bow' => true,
  'bor' => true,
  'bol' => true,
  'boc' => true,
  'ber' => true,
  'bay' => true,
  'bag' => true,
  'bab' => true,
  'azu' => true,
  'ase' => true,
  'asa' => true,
  'art' => true,
  'arm' => true,
  'ami' => true,
  'age' => true,
  'abb' => true,
  'ab1' => true,
  'aas' => true,
  'yoy' => true,
  'tri' => true,
  'toy' => true,
  'thx' => true,
  'rxd' => true,
  'pro' => true,
  'mdz' => true,
  'mdw' => true,
  'mds' => true,
  'mdn' => true,
  'mdg' => true,
  'mde' => true,
  'mdx' => true,
  'mdh' => true,
  'md3' => true,
  'md2' => true,
  'md0' => true,
  'gt+' => true,
  'giu' => true,
  'epw' => true,
  'bbc' => true,
  'and' => true,
  '9am' => true,
  987 => true,
  972 => true,
  951 => true,
  949 => true,
  947 => true,
  '92p' => true,
  923 => true,
  901 => true,
  '88x' => true,
  863 => true,
  862 => true,
  '85z' => true,
  840 => true,
  831 => true,
  824 => true,
  817 => true,
  802 => true,
  '79e' => true,
  '79y' => true,
  792 => true,
  788 => true,
  753 => true,
  '72f' => true,
  728 => true,
  725 => true,
  720 => true,
  '71q' => true,
  712 => true,
  698 => true,
  696 => true,
  691 => true,
  683 => true,
  654 => true,
  652 => true,
  627 => true,
  617 => true,
  611 => true,
  '59l' => true,
  '59j' => true,
  596 => true,
  592 => true,
  582 => true,
  580 => true,
  570 => true,
  '56n' => true,
  558 => true,
  '53s' => true,
  526 => true,
  512 => true,
  '4me' => true,
  486 => true,
  '46t' => true,
  '45e' => true,
  452 => true,
  450 => true,
  448 => true,
  432 => true,
  430 => true,
  '42w' => true,
  414 => true,
  411 => true,
  '40v' => true,
  '40t' => true,
  406 => true,
  401 => true,
  390 => true,
  389 => true,
  384 => true,
  '37u' => true,
  379 => true,
  378 => true,
  359 => true,
  346 => true,
  '33x' => true,
  335 => true,
  327 => true,
  '31m' => true,
  318 => true,
  310 => true,
  304 => true,
  300 => true,
  299 => true,
  283 => true,
  282 => true,
  280 => true,
  271 => true,
  264 => true,
  263 => true,
  262 => true,
  260 => true,
  259 => true,
  255 => true,
  '24k' => true,
  238 => true,
  237 => true,
  233 => true,
  231 => true,
  223 => true,
  220 => true,
  '21o' => true,
  214 => true,
  '20i' => true,
  205 => true,
  203 => true,
  194 => true,
  192 => true,
  187 => true,
  184 => true,
  179 => true,
  176 => true,
  173 => true,
  171 => true,
  169 => true,
  163 => true,
  '15x' => true,
  156 => true,
  153 => true,
  146 => true,
  144 => true,
  143 => true,
  136 => true,
  128 => true,
  126 => true,
  118 => true,
  116 => true,
  115 => true,
  114 => true,
  '098' => true,
  '094' => true,
  '091' => true,
  '081' => true,
  '052' => true,
  '041' => true,
  '040' => true,
  '035' => true,
  '032' => true,
  '022' => true,
  '021' => true,
  '012' => true,
  '010' => true,
  '+en' => true,
  '***' => true,
  'zxl' => true,
  'zub' => true,
  'zog' => true,
  'zoe' => true,
  'zn0' => true,
  'zln' => true,
  'zip' => true,
  'zia' => true,
  'zgh' => true,
  'zgn' => true,
  'zep' => true,
  'zee' => true,
  'zaz' => true,
  'zax' => true,
  'zap' => true,
  'zab' => true,
  'zk4' => true,
  'z9q' => true,
  'z86' => true,
  'z61' => true,
  'z0q' => true,
  'yyy' => true,
  'yuy' => true,
  'yur' => true,
  'yuj' => true,
  'yuc' => true,
  'ys3' => true,
  'yre' => true,
  'yrv' => true,
  'yok' => true,
  'yir' => true,
  'yhy' => true,
  'yey' => true,
  'yen' => true,
  'ydv' => true,
  'yby' => true,
  'yam' => true,
  'yak' => true,
  'ywy' => true,
  'yhu' => true,
  'xxl' => true,
  'xvi' => true,
  'xux' => true,
  'xuy' => true,
  'xtc' => true,
  'xp0' => true,
  'xox' => true,
  'xof' => true,
  'xim' => true,
  'xia' => true,
  'xi9' => true,
  'xyk' => true,
  'xuo' => true,
  'xty' => true,
  'x82' => true,
  'x75' => true,
  'x2y' => true,
  'x27' => true,
  'x0a' => true,
  'wwf' => true,
  'wuo' => true,
  'wtp' => true,
  'wsb' => true,
  'wrd' => true,
  'wr3' => true,
  'wp9' => true,
  'woo' => true,
  'wol' => true,
  'wns' => true,
  'wip' => true,
  'win' => true,
  'wil' => true,
  'wi1' => true,
  'who' => true,
  'wen' => true,
  'wel' => true,
  'wee' => true,
  'wax' => true,
  'waw' => true,
  'was' => true,
  'wal' => true,
  'wty' => true,
  'wo2' => true,
  'wjr' => true,
  'wjo' => true,
  'wjg' => true,
  'w82' => true,
  'vvv' => true,
  'vuk' => true,
  'vtt' => true,
  'vny' => true,
  'vlp' => true,
  'vis' => true,
  'ver' => true,
  'ven' => true,
  'vel' => true,
  'veg' => true,
  'vb0' => true,
  'vam' => true,
);
